edipy
=====

**edipy** gives you a fancy way to read positional files by using declarative classes.

Documentation
-------------

Soon you can find docs at the [Read the docs](https://edipy.readthedocs.io/en/latest/) website.
